cwlVersion: v1.2
class: Workflow
doc: >-
  A file containing GEO Aging Signatures was first uploaded. The file containing
  GEO Aging Signatures was loaded as a gene signature. A file containing GTEx
  Aging Signatures was first uploaded. The file containing GTEx Aging Signatures
  was loaded as a gene signature. Significant genes were extracted from the GEO
  Aging Signatures. Significant genes were extracted from the GTEx Aging
  Signatures. Reversers and mimickers from over 1 million signatures were
  identified using SigCom LINCS[1]. Resolved drugs from the LINCS L1000 Chemical
  Perturbagens library. Reversers and mimickers from over 1 million signatures
  were identified using SigCom LINCS[1]. Resolved drugs from the LINCS L1000
  Chemical Perturbagens library. The mean across multiple Scored Drugs is
  computed. The drugs were filtered by FDA Approved Drugs with the help of
  PubChem APIs[3]. 

  1. Evangelista, J. E. et al. SigCom LINCS: data and metadata search engine for
  a million gene expression signatures. Nucleic Acids Research vol. 50 W697–W709
  (2022). doi:10.1093/nar/gkac328

  3. Kim, S. et al. PubChem 2023 update. Nucleic Acids Research vol. 51
  D1373–D1380 (2022). doi:10.1093/nar/gkac956
requirements: {}
inputs:
  step-1-data:
    label: Input File
    doc: Upload a Data File
    type: File
  step-3-data:
    label: Input File
    doc: Upload a Data File
    type: File
outputs:
  step-1-output:
    label: File URL
    doc: URL to a File
    type: File
    outputSource: step-1/output
  step-2-output:
    label: Gene Signature
    doc: A gene expression signature
    type: File
    outputSource: step-2/output
  step-3-output:
    label: File URL
    doc: URL to a File
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Gene Signature
    doc: A gene expression signature
    type: File
    outputSource: step-4/output
  step-5-output:
    label: Scored Genes
    doc: ZScores of Genes
    type: File
    outputSource: step-5/output
  step-6-output:
    label: Scored Genes
    doc: ZScores of Genes
    type: File
    outputSource: step-6/output
  step-7-output:
    label: SigCom LINCS Signature Search Results
    doc: LINCS L1000 Signatures Query Results
    type: File
    outputSource: step-7/output
  step-8-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-8/output
  step-9-output:
    label: SigCom LINCS Signature Search Results
    doc: LINCS L1000 Signatures Query Results
    type: File
    outputSource: step-9/output
  step-10-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-10/output
  step-11-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-11/output
  step-12-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-12/output
steps:
  step-1:
    run: FileInput.cwl
    label: Input File
    doc: Upload a Data File
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: GeneSigFromFile.cwl
    label: Resolve a Gene Signature from a File
    doc: Load a gene signature into a standard format
    in:
      inputs.file:
        label: File URL
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: FileInput.cwl
    label: Input File
    doc: Upload a Data File
    in:
      data:
        source: step-3-data
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: GeneSigFromFile.cwl
    label: Resolve a Gene Signature from a File
    doc: Load a gene signature into a standard format
    in:
      inputs.file:
        label: File URL
        source: step-3/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: ScoredGenesFromSignature.cwl
    label: Scored Genes from Signature
    doc: Treat signature as a weighted set of genes
    in:
      inputs.sig:
        label: Gene Signature
        source: step-2/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
  step-6:
    run: ScoredGenesFromSignature.cwl
    label: Scored Genes from Signature
    doc: Treat signature as a weighted set of genes
    in:
      inputs.sig:
        label: Gene Signature
        source: step-4/output
      outputFilename:
        default: step-6-output.json
    out:
      - output
  step-7:
    run: SigComLINCSSignatureSearch.cwl
    label: SigCom LINCS Signature Search
    doc: Query LINCS L1000 Signatures
    in:
      inputs.genes:
        label: Scored Genes
        source: step-6/output
      outputFilename:
        default: step-7-output.json
    out:
      - output
  step-8:
    run: ExtractSigComLINCSSignatureSearch[LINCS L1000 Chemical Perturbagens].cwl
    label: Extract LINCS L1000 Chemical Perturbagens
    doc: Extract signatures from the results
    in:
      inputs.searchResults:
        label: SigCom LINCS Signature Search Results
        source: step-7/output
      outputFilename:
        default: step-8-output.json
    out:
      - output
  step-9:
    run: SigComLINCSSignatureSearch.cwl
    label: SigCom LINCS Signature Search
    doc: Query LINCS L1000 Signatures
    in:
      inputs.genes:
        label: Scored Genes
        source: step-5/output
      outputFilename:
        default: step-9-output.json
    out:
      - output
  step-10:
    run: ExtractSigComLINCSSignatureSearch[LINCS L1000 Chemical Perturbagens].cwl
    label: Extract LINCS L1000 Chemical Perturbagens
    doc: Extract signatures from the results
    in:
      inputs.searchResults:
        label: SigCom LINCS Signature Search Results
        source: step-9/output
      outputFilename:
        default: step-10-output.json
    out:
      - output
  step-11:
    run: MeanScoredT[Drug].cwl
    label: Mean Scored Values
    doc: Take the mean value across multiple scores
    in:
      inputs.scored:0:
        label: Scored Drugs
        source: step-8/output
      inputs.scored:1:
        label: Scored Drugs
        source: step-10/output
      outputFilename:
        default: step-11-output.json
    out:
      - output
  step-12:
    run: FilterFDAApprovedDrugs[Scored[Drug]].cwl
    label: Extract FDA Approved Drugs
    doc: Filter the drugs with PubChem APIs
    in:
      inputs.drugs:
        label: Scored Drugs
        source: step-11/output
      outputFilename:
        default: step-12-output.json
    out:
      - output
